==> deepin-camera_1.1.2.orig.tar.xz: deepin-camera-1.1.2/src/translations/deepin-camera_sq.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Po kryhet regjistrim videoje. Të mbyllet dritarja?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Hap dosjen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Mbylle</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Hap dosjen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Shtypje</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>S’keni leje të veproni në këtë dosje</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Mbylle</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Dosje e pavlefshme</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Hap dosjen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Elementare</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Vendndodhje kartele</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Shkrepe</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Metodë shkrepjesh të vazhdueshme</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Vonesë kohëmatësi automatik</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Përfundim</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format përfundimi</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 copë</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 copë</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamerë</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera është një mjet për bërje fotosh dhe videosh duke përdorur kamerën e PC-së tuaj ose një kamerë web.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Kartela s’u ruajt</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Ruaje te:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Rregullime qartësie</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Qartësi:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efekte zanore</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamerë</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Resht së regjistruari</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Hape</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Shtypje</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Shfaq shkurtore</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Resht së bëri foto</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu konteksti</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Bëni foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Regjistroni video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Resht së bëri foto</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>S’u gjet kamerë web</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Kamera web është në përdorim</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Resht së regjistruari</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.3.7.1.orig.tar.xz: deepin-camera-1.3.7.1/src/translations/deepin-camera_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Po kryhet regjistrim videoje. Të mbyllet dritarja?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Hap dosjen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Ndërroni Kamera</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Mbylle</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Hap dosjen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Shtypje</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>S’keni leje të veproni në këtë dosje</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Mbylle</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Dosje e pavlefshme</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Hap dosjen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Elementare</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Vendndodhje kartele</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Shkrepe</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Metodë shkrepjesh të vazhdueshme</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Vonesë kohëmatësi automatik</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Përfundim</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format përfundimi</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 copë</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 copë</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamerë</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera është një mjet për bërje fotosh dhe videosh duke përdorur kamerën e PC-së tuaj ose një kamerë web.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Kartela s’u ruajt</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Ruaje te:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Rregullime qartësie</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Qartësi:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efekte zanore</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Mënyra pasqyrë</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamerë</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Resht së regjistruari</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Hape</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Shtypje</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Shfaq shkurtore</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Resht së bëri foto</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu konteksti</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Bëni foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Regjistroni video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Resht së bëri foto</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Asnjë</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>E gjallë</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>E ngrohtë</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>E ftohtë</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gri</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;Z</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Off</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Vonesë shkrepjeje</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtra</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Ekspozim</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>S’u gjet kamerë web</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Kamera web është në përdorim</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Resht së regjistruari</translation>
    </message>
</context>
</TS>
